Error

Enum Error 

pub enum Error {
Show 18 variants NotFound, ParseError, ConversionError, OutOfBoundsError, MalformedDataError, WrongSectionError, WrongTypeError, FromComplexError, FromPrimitiveError(String), PoisonError(String), FromBytesWithNulError(FromBytesWithNulError), FromStringError(NulError), IntoStringError(IntoStringError), InfallibleError(Infallible), ParseValueError(TryFromSliceError), ParseUtf8Error(Utf8Error), IOError(Error), IntConvertError(TryFromIntError),
}
Custom error type used everywhere in this crate

Variants



NotFound

A resource could not be found



ParseError

Binary data could not be parsed into fields



ConversionError

A value could not be converted to a different representation



OutOfBoundsError

Collection was accessed with an out-of-bounds index



MalformedDataError

Given data has missing or wrong values for the action



WrongSectionError

Filed to convert section to a table or array



WrongTypeError

Filed to convert type to some specialized type



FromComplexError

Could not parse complex type from primitive



FromPrimitiveError(String)

Could not parse complex type from primitive



PoisonError(String)

Failed to access shared data because Mutex is poisoned



FromBytesWithNulError(FromBytesWithNulError)

Bytes with no nul terminator could not be parsed as c-string



FromStringError(NulError)

String with no nul terminator could not be parsed as c-string



IntoStringError(IntoStringError)

CString failed to convert to UTF-8 encoded String



InfallibleError(Infallible)

This error will never actually be created



ParseValueError(TryFromSliceError)

Failed to convert bytes to a value representation



ParseUtf8Error(Utf8Error)

Bytes could not be converted to UTF-8 encoded String



IOError(Error)

Could not open a file for reading



IntConvertError(TryFromIntError)

Could not convert integer to a different integer type